==> mathfox-1.1.1.tar.gz: mathfox-1.1.1/README.md <==
# MathFox

A library with math functions to help **Python** developers with their projects.

In total, we have **39** functions, **1** variable and **1** class!

[![GitHub License](https://img.shields.io/github/license/PipocaFox/MathFox?color=orange)](https://github.com/PipocaFox/MathFox/blob/main/LICENCE)
![PyPI - Version](https://img.shields.io/pypi/v/MathFox?label=version)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mathfox?color=green)
![GitHub commit activity (branch)](https://img.shields.io/github/commit-activity/m/PipocaFox/MathFox?logo=github&color=red)
![PyPI - Downloads](https://img.shields.io/pypi/dm/mathfox?logo=pypi&logoColor=white&color=yellow)

[![Static Badge](https://img.shields.io/badge/Documentation-%20?logo=github&color=black)](https://github.com/PipocaFox/MathFox/blob/main/DOCUMENTATION.md)


### MathFox link on:

[![Static Badge](https://img.shields.io/badge/Github-%20?logo=github&color=black)](https://github.com/PipocaFox/MathFox)
[![Static Badge](https://img.shields.io/badge/PYPI-%20?logo=pypi&logoColor=white&color=blue)](https://pypi.org/project/mathfox)


---

## Versions
- [**v1.1.1**](https://pypi.org/project/mathfox/1.1.1/) **LATTER** **---**
improvement of trigonometric functions and addition of the ``cot()``, ``sec()`` and ``csc()`` functions, in addition to the ``radians()`` and ``degrees()`` function which is in the **calculation** category 
- [**v1.1.0**](https://pypi.org/project/mathfox/1.1.0/) **---**
Removal of the `sumlist()` function, creation of the `Fraction()` class, renaming of the `isfloat()` function to `isdecimal()` and **math** category for **calculation** category, creation of a new category in the **calculation** category, which is **geometry**, within it will be the **area** category (which has been redefined), and the **trigonometry** category, which will have, in addition to the ``sin()``, ``cos()`` and ``tan()`` functions, it will have the ``asin()``, ``acos()`` and ``atan()`` functions.
- [**v1.0.2**](https://pypi.org/project/mathfox/1.0.2/) **---**
Correction of the `chance()` function, improvement of the `isint()` and `isfloat()` functions, creation of more decent documentation.
- [**v1.0.0**](https://pypi.org/project/mathfox/1.0.0/) **---** 
Library creation.

---

## Library structure
- mathfox
    - calculation
      - geometry
          - area
            - two_dimensions
            - three_dimensions
          - trigonometry
    - number
    - numis
  

---

## Installation
Open **CMD** and write:
```
pip install --upgrade mathfox
```

---

==> mathfox-1.1.2b1.tar.gz: mathfox-1.1.2b1/README.md <==
![MathFox](https://github.com/PipocaFox/MathFox/assets/114585145/60aa9f15-3796-4b6c-81f9-6663075fcb19)

---

A library with math functions to help **Python** developers with their projects.

In total, we have **44** functions, **1** variable and **2** class!

[![GitHub License](https://img.shields.io/github/license/PipocaFox/MathFox?color=orange)](https://github.com/PipocaFox/MathFox/blob/main/LICENCE)
![PyPI - Version](https://img.shields.io/pypi/v/MathFox?label=version)
![Python Version](https://img.shields.io/badge/python-%3E%3D3.6-green)
![GitHub commit activity (branch)](https://img.shields.io/github/commit-activity/m/PipocaFox/MathFox?logo=github&color=red)
![PyPI - Downloads](https://img.shields.io/pypi/dm/mathfox?logo=pypi&logoColor=white&color=yellow)

[![Static Badge](https://img.shields.io/badge/Documentation-%20?logo=github&color=black)](https://github.com/PipocaFox/MathFox/blob/main/DOCUMENTATION.md)


### MathFox link on:

[![Static Badge](https://img.shields.io/badge/Github-%20?logo=github&color=black)](https://github.com/PipocaFox/MathFox)
[![Static Badge](https://img.shields.io/badge/PYPI-%20?logo=pypi&logoColor=white&color=blue)](https://pypi.org/project/mathfox)


---

## Versions
- [**v1.1.2b1**](https://pypi.org/project/mathfox/1.1.2b1/) **LATTER** **---**
Addition of new statistical functions such as `median()`, `mode()`, `std()` and `var()`, and a new function that is `hypotenuse()`. We renamed some categories, such as **calculation** to **cal**, **geometry** to **geo** and **trigonometry** to **trigo**, and some functions such as `arcsin()`, `arccos()` and `arctan()`. We also added a new class which is `Decimal()` and a function which is `array()` which is under development, so its use is not recommended.


- [**v1.1.1**](https://pypi.org/project/mathfox/1.1.1/) **RECOMMENDED** **---**
improvement of trigonometric functions and addition of the ``cot()``, ``sec()`` and ``csc()`` functions, in addition to the ``radians()`` and ``degrees()`` function which is in the **calculation** category 


- [**v1.1.0**](https://pypi.org/project/mathfox/1.1.0/) **---**
Removal of the `sumlist()` function, creation of the `Fraction()` class, renaming of the `isfloat()` function to `isdecimal()` and **math** category for **calculation** category, creation of a new category in the **calculation** category, which is **geometry**, within it will be the **area** category (which has been redefined), and the **trigonometry** category, which will have, in addition to the ``sin()``, ``cos()`` and ``tan()`` functions, it will have the ``asin()``, ``acos()`` and ``atan()`` functions.


- [**v1.0.2**](https://pypi.org/project/mathfox/1.0.2/) **---**
Correction of the `chance()` function, improvement of the `isint()` and `isfloat()` functions, creation of more decent documentation.


- [**v1.0.0**](https://pypi.org/project/mathfox/1.0.0/) **---** 
Library creation.

---

## Library structure
- mathfox
    - cal
      - geo
          - area
            - two_dimensions
            - three_dimensions
          - trigo
    - number
    - numis
  

---

## Installation

### PYPI
Open **CMD** and write:
```
pip install --upgrade mathfox
```

### Git
1. Open **CMD** and write:
```
git clone https://github.com/PipocaFox/MathFox
```

2. Go to the MathFox folder:
```
cd mathfox
```

3. Now run the installer:
```
python install.py
```
---
